[PHP-CVS-DAILY] cvs: ZendEngine2 / ChangeLog

2004-10-30 Thread changelog
changelog   Sat Oct 30 20:52:50 2004 EDT

  Modified files:  
/ZendEngine2ChangeLog 
  Log:
  ChangeLog update
  
http://cvs.php.net/diff.php/ZendEngine2/ChangeLog?r1=1.580r2=1.581ty=u
Index: ZendEngine2/ChangeLog
diff -u ZendEngine2/ChangeLog:1.580 ZendEngine2/ChangeLog:1.581
--- ZendEngine2/ChangeLog:1.580 Fri Oct 29 20:46:12 2004
+++ ZendEngine2/ChangeLog   Sat Oct 30 20:52:50 2004
@@ -1,3 +1,45 @@
+2004-10-30  Marcus Boerger  [EMAIL PROTECTED]
+
+* zend.h:
+  Bump version (as discussed with Andi)
+
+* (PHP_5_0)
+  zend_execute.c:
+  - Fix (readd function name which got lost during earlier comit)
+
+* zend_reflection_api.c:
+  - Be consistent and use names as keys (found by johannes)
+
+* zend_extensions.h
+  zend_modules.h:
+  - Bump API version
+
+* (PHP_5_0)
+  zend_extensions.h
+  zend_modules.h:
+  Bump api after latest changes
+
+* (PHP_5_0)
+  zend_execute.c
+  zend_object_handlers.c
+  zend_object_handlers.h:
+  MFH change zend_object_handlers-get_method()
+
+* zend_execute_API.c
+  zend_object_handlers.c
+  zend_object_handlers.h
+  zend_vm_def.h
+  zend_vm_execute.h:
+  - Change zend_object_handlers-get_method() to allow aggregation for
+  internal classes
+
+* Makefile.frag:
+  - New architecture needs one more dependency
+
+* zend_exceptions.c
+  zend_reflection_api.c:
+  - Fix protos
+
 2004-10-29  Andi Gutmans  [EMAIL PROTECTED]
 
 * zend_operators.c:
@@ -6155,7 +6197,7 @@
 2003-06-10  Jani Taskinen  [EMAIL PROTECTED]
 
 * zend_multiply.h:
-  - Missing $Id: ChangeLog,v 1.580 2004/10/30 00:46:12 changelog Exp $ tag
+  - Missing $Id: ChangeLog,v 1.581 2004/10/31 00:52:50 changelog Exp $ tag
 
 2003-06-10  James Cox  [EMAIL PROTECTED]
 
@@ -7879,7 +7921,7 @@
   zend_types.h
   zend_variables.c
   zend_variables.h:
-  - Added some missing CVS $Id: ChangeLog,v 1.580 2004/10/30 00:46:12 changelog 
Exp $ tags, headers and footers.
+  - Added some missing CVS $Id: ChangeLog,v 1.581 2004/10/31 00:52:50 changelog 
Exp $ tags, headers and footers.
 
 2003-01-30  Ilia Alshanetsky  [EMAIL PROTECTED]
 


[PHP-CVS] cvs: php-src /ext/spl spl_iterators.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 06:04:39 2004 EDT

  Modified files:  
/php-src/ext/splspl_iterators.c 
  Log:
  - Fix proto
  
http://cvs.php.net/diff.php/php-src/ext/spl/spl_iterators.c?r1=1.41r2=1.42ty=u
Index: php-src/ext/spl/spl_iterators.c
diff -u php-src/ext/spl/spl_iterators.c:1.41 php-src/ext/spl/spl_iterators.c:1.42
--- php-src/ext/spl/spl_iterators.c:1.41Fri Oct 29 16:12:54 2004
+++ php-src/ext/spl/spl_iterators.c Sat Oct 30 06:04:37 2004
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: spl_iterators.c,v 1.41 2004/10/29 20:12:54 helly Exp $ */
+/* $Id: spl_iterators.c,v 1.42 2004/10/30 10:04:37 helly Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include config.h
@@ -317,7 +317,7 @@
spl_recursive_it_rewind
 };
 
-/* {{{ proto RecursiveIteratorIterator::__construct(RecursiveIterator $it)
+/* {{{ proto RecursiveIteratorIterator::__construct(RecursiveIterator it, int flags)
Creates a RecursiveIteratorIterator from a RecursiveIterator. */
 SPL_METHOD(RecursiveIteratorIterator, __construct)
 {

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src /ext/spl spl_iterators.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 06:18:11 2004 EDT

  Modified files:  
/php-src/ext/splspl_iterators.c 
  Log:
  - Fix protos
  
http://cvs.php.net/diff.php/php-src/ext/spl/spl_iterators.c?r1=1.42r2=1.43ty=u
Index: php-src/ext/spl/spl_iterators.c
diff -u php-src/ext/spl/spl_iterators.c:1.42 php-src/ext/spl/spl_iterators.c:1.43
--- php-src/ext/spl/spl_iterators.c:1.42Sat Oct 30 06:04:37 2004
+++ php-src/ext/spl/spl_iterators.c Sat Oct 30 06:18:10 2004
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: spl_iterators.c,v 1.42 2004/10/30 10:04:37 helly Exp $ */
+/* $Id: spl_iterators.c,v 1.43 2004/10/30 10:18:10 helly Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include config.h
@@ -317,7 +317,7 @@
spl_recursive_it_rewind
 };
 
-/* {{{ proto RecursiveIteratorIterator::__construct(RecursiveIterator it, int flags)
+/* {{{ proto RecursiveIteratorIterator::__construct(RecursiveIterator it [, int flags 
= RIT_LEAVES_ONLY])
Creates a RecursiveIteratorIterator from a RecursiveIterator. */
 SPL_METHOD(RecursiveIteratorIterator, __construct)
 {
@@ -622,7 +622,7 @@
return intern;
 }
 
-/* {{{ proto FilterIterator::__construct(Iterator $it) 
+/* {{{ proto FilterIterator::__construct(Iterator it) 
Create an Iterator from another iterator */
 SPL_METHOD(dual_it, __construct)
 {
@@ -852,7 +852,7 @@
spl_filter_it_next(getThis(), intern TSRMLS_CC);
 } /* }}} */
 
-/* {{{ proto ParentIterator::__construct(RecursiveIterator $it)
+/* {{{ proto ParentIterator::__construct(RecursiveIterator it)
Create a ParentIterator from a RecursiveIterator */
 SPL_METHOD(ParentIterator, __construct)
 {
@@ -1008,7 +1008,7 @@
}
 }
 
-/* {{{ proto LimitIterator::__construct(Iterator $it [, int $offset, int $count])
+/* {{{ proto LimitIterator::__construct(Iterator it [, int offset, int count])
Construct a LimitIterator from an Iterator with a given starting offset and 
optionally a maximum count */
 SPL_METHOD(LimitIterator, __construct)
 {
@@ -1052,7 +1052,7 @@
}
 } /* }}} */
 
-/* {{{ proto void LimitIterator::seek(int $position)
+/* {{{ proto void LimitIterator::seek(int position)
Seek to the given position */
 SPL_METHOD(LimitIterator, seek)
 {
@@ -1200,7 +1200,7 @@
spl_caching_it_next(intern TSRMLS_CC);
 }
 
-/* {{{ proto CachingIterator::__construct(Iterator $it)
+/* {{{ proto CachingIterator::__construct(Iterator it [, flags = CIT_CALL_TOSTRING])
Construct a CachingIterator from an Iterator */
 SPL_METHOD(CachingIterator, __construct)
 {
@@ -1288,7 +1288,7 @@
{NULL, NULL, NULL}
 };
 
-/* {{{ proto CachingRecursiveIterator::__construct(RecursiveIterator $it)
+/* {{{ proto CachingRecursiveIterator::__construct(RecursiveIterator it [, flags = 
CIT_CALL_TOSTRING])
Create an iterator from a RecursiveIterator */
 SPL_METHOD(CachingRecursiveIterator, __construct)
 {
@@ -1335,7 +1335,7 @@
{NULL, NULL, NULL}
 };
 
-/* {{{ array iterator_to_array(IteratorAggregate $it) 
+/* {{{ array iterator_to_array(IteratorAggregate it) 
Copy the iterator into an array */
 PHP_FUNCTION(iterator_to_array)
 {
@@ -1374,7 +1374,7 @@
 }
 /* }}} */
 
-/* {{{ int iterator_count(IteratorAggregate $it) 
+/* {{{ int iterator_count(IteratorAggregate it) 
Count the elements in an iterator */
 PHP_FUNCTION(iterator_count)
 {

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src /ext/spl spl_directory.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 10:33:28 2004 EDT

  Modified files:  
/php-src/ext/splspl_directory.c 
  Log:
  strip trailing (back)slash from path
  
http://cvs.php.net/diff.php/php-src/ext/spl/spl_directory.c?r1=1.27r2=1.28ty=u
Index: php-src/ext/spl/spl_directory.c
diff -u php-src/ext/spl/spl_directory.c:1.27 php-src/ext/spl/spl_directory.c:1.28
--- php-src/ext/spl/spl_directory.c:1.27Fri Sep  3 14:39:30 2004
+++ php-src/ext/spl/spl_directory.c Sat Oct 30 10:33:25 2004
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: spl_directory.c,v 1.27 2004/09/03 18:39:30 helly Exp $ */
+/* $Id: spl_directory.c,v 1.28 2004/10/30 14:33:25 helly Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include config.h
@@ -120,9 +120,14 @@
 /* open a directory resource */
 static void spl_ce_dir_open(spl_ce_dir_object* intern, char *path TSRMLS_DC)
 {
+   int path_len = strlen(path);
intern-dirp = php_stream_opendir(path, ENFORCE_SAFE_MODE|REPORT_ERRORS, NULL);
 
-   intern-path = estrdup(path);
+   if (path_len  (path[path_len-1] == '/' || path[path_len-1] == '\\')) {
+   intern-path = estrndup(path, --path_len);
+   } else {
+   intern-path = estrndup(path, path_len);
+   }
intern-index = 0;
 
if (intern-dirp == NULL) {



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src(PHP_5_0) /ext/spl spl_directory.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 10:35:01 2004 EDT

  Modified files:  (Branch: PHP_5_0)
/php-src/ext/splspl_directory.c 
  Log:
  MFH
  
http://cvs.php.net/diff.php/php-src/ext/spl/spl_directory.c?r1=1.26.2.1r2=1.26.2.2ty=u
Index: php-src/ext/spl/spl_directory.c
diff -u php-src/ext/spl/spl_directory.c:1.26.2.1 
php-src/ext/spl/spl_directory.c:1.26.2.2
--- php-src/ext/spl/spl_directory.c:1.26.2.1Fri Sep  3 14:41:10 2004
+++ php-src/ext/spl/spl_directory.c Sat Oct 30 10:35:01 2004
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: spl_directory.c,v 1.26.2.1 2004/09/03 18:41:10 helly Exp $ */
+/* $Id: spl_directory.c,v 1.26.2.2 2004/10/30 14:35:01 helly Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include config.h
@@ -120,9 +120,15 @@
 /* open a directory resource */
 static void spl_ce_dir_open(spl_ce_dir_object* intern, char *path TSRMLS_DC)
 {
+   int path_len = strlen(path);
+
intern-dirp = php_stream_opendir(path, ENFORCE_SAFE_MODE|REPORT_ERRORS, NULL);
 
-   intern-path = estrdup(path);
+   if (path_len  (path[path_len-1] == '/' || path[path_len-1] == '\\')) {
+   intern-path = estrndup(path, --path_len);
+   } else {
+   intern-path = estrndup(path, path_len);
+   }
intern-index = 0;
 
if (intern-dirp == NULL) {

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src(PHP_5_0) /ext/standard incomplete_class.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 15:17:21 2004 EDT

  Modified files:  (Branch: PHP_5_0)
/php-src/ext/standard   incomplete_class.c 
  Log:
  MFH
  
http://cvs.php.net/diff.php/php-src/ext/standard/incomplete_class.c?r1=1.24.2.1r2=1.24.2.2ty=u
Index: php-src/ext/standard/incomplete_class.c
diff -u php-src/ext/standard/incomplete_class.c:1.24.2.1 
php-src/ext/standard/incomplete_class.c:1.24.2.2
--- php-src/ext/standard/incomplete_class.c:1.24.2.1Sun Sep  5 13:40:54 2004
+++ php-src/ext/standard/incomplete_class.c Sat Oct 30 15:17:21 2004
@@ -17,7 +17,7 @@
  */
 
 
-/* $Id: incomplete_class.c,v 1.24.2.1 2004/09/05 17:40:54 helly Exp $ */
+/* $Id: incomplete_class.c,v 1.24.2.2 2004/10/30 19:17:21 helly Exp $ */
 
 #include php.h
 #include basic_functions.h
@@ -82,8 +82,8 @@
return 0;
 }
 
-static union _zend_function *incomplete_class_get_method(zval *object, char *method, 
int method_len TSRMLS_DC) {
-   incomplete_class_message(object, E_ERROR TSRMLS_CC);
+static union _zend_function *incomplete_class_get_method(zval **object_ptr, char 
*method, int method_len TSRMLS_DC) {
+   incomplete_class_message(*object_ptr, E_ERROR TSRMLS_CC);
return NULL;
 }
 

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src(PHP_5_0) /ext/spl spl_iterators.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 15:22:00 2004 EDT

  Modified files:  (Branch: PHP_5_0)
/php-src/ext/splspl_iterators.c 
  Log:
  MFH
  
http://cvs.php.net/diff.php/php-src/ext/spl/spl_iterators.c?r1=1.38.2.2r2=1.38.2.3ty=u
Index: php-src/ext/spl/spl_iterators.c
diff -u php-src/ext/spl/spl_iterators.c:1.38.2.2 
php-src/ext/spl/spl_iterators.c:1.38.2.3
--- php-src/ext/spl/spl_iterators.c:1.38.2.2Sat Oct 30 06:46:24 2004
+++ php-src/ext/spl/spl_iterators.c Sat Oct 30 15:21:59 2004
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: spl_iterators.c,v 1.38.2.2 2004/10/30 10:46:24 helly Exp $ */
+/* $Id: spl_iterators.c,v 1.38.2.3 2004/10/30 19:21:59 helly Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include config.h
@@ -489,18 +489,19 @@
 }
 #endif
 
-static union _zend_function *spl_dual_it_get_method(zval *object, char *method, int 
method_len TSRMLS_DC)
+static union _zend_function *spl_dual_it_get_method(zval **object_ptr, char *method, 
int method_len TSRMLS_DC)
 {
union _zend_function *function_handler;
spl_dual_it_object   *intern;
 
-   intern = (spl_dual_it_object*)zend_object_store_get_object(object TSRMLS_CC);
+   intern = (spl_dual_it_object*)zend_object_store_get_object(*object_ptr 
TSRMLS_CC);
 
-   function_handler = std_object_handlers.get_method(object, method, method_len 
TSRMLS_CC);
+   function_handler = std_object_handlers.get_method(object_ptr, method, 
method_len TSRMLS_CC);
if (!function_handler) {
if (zend_hash_find(intern-inner.ce-function_table, method, 
method_len+1, (void **) function_handler) == FAILURE) {
if (Z_OBJ_HT_P(intern-inner.zobject)-get_method) {
-   function_handler = 
Z_OBJ_HT_P(intern-inner.zobject)-get_method(intern-inner.zobject, method, 
method_len TSRMLS_CC);
+   *object_ptr = intern-inner.zobject;
+   function_handler = 
Z_OBJ_HT_P(*object_ptr)-get_method(object_ptr, method, method_len TSRMLS_CC);
}
}
}
@@ -609,7 +610,7 @@
return intern;
 }
 
-/* {{{ proto FilterIterator::__construct(Iterator $it) 
+/* {{{ proto FilterIterator::__construct(Iterator it) 
Create an Iterator from another iterator */
 SPL_METHOD(dual_it, __construct)
 {

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src /ext/standard incomplete_class.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 15:14:05 2004 EDT

  Modified files:  
/php-src/ext/standard   incomplete_class.c 
  Log:
  - Update to new API
  
http://cvs.php.net/diff.php/php-src/ext/standard/incomplete_class.c?r1=1.25r2=1.26ty=u
Index: php-src/ext/standard/incomplete_class.c
diff -u php-src/ext/standard/incomplete_class.c:1.25 
php-src/ext/standard/incomplete_class.c:1.26
--- php-src/ext/standard/incomplete_class.c:1.25Sun Sep  5 13:37:57 2004
+++ php-src/ext/standard/incomplete_class.c Sat Oct 30 15:14:05 2004
@@ -17,7 +17,7 @@
  */
 
 
-/* $Id: incomplete_class.c,v 1.25 2004/09/05 17:37:57 helly Exp $ */
+/* $Id: incomplete_class.c,v 1.26 2004/10/30 19:14:05 helly Exp $ */
 
 #include php.h
 #include basic_functions.h
@@ -82,8 +82,8 @@
return 0;
 }
 
-static union _zend_function *incomplete_class_get_method(zval *object, char *method, 
int method_len TSRMLS_DC) {
-   incomplete_class_message(object, E_ERROR TSRMLS_CC);
+static union _zend_function *incomplete_class_get_method(zval **object, char *method, 
int method_len TSRMLS_DC) {
+   incomplete_class_message(*object, E_ERROR TSRMLS_CC);
return NULL;
 }
 

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] cvs: php-src(PHP_5_0) /ext/spl spl_iterators.c

2004-10-30 Thread Marcus Boerger
helly   Sat Oct 30 06:46:26 2004 EDT

  Modified files:  (Branch: PHP_5_0)
/php-src/ext/splspl_iterators.c 
  Log:
  MFH Fix protos
  
http://cvs.php.net/diff.php/php-src/ext/spl/spl_iterators.c?r1=1.38.2.1r2=1.38.2.2ty=u
Index: php-src/ext/spl/spl_iterators.c
diff -u php-src/ext/spl/spl_iterators.c:1.38.2.1 
php-src/ext/spl/spl_iterators.c:1.38.2.2
--- php-src/ext/spl/spl_iterators.c:1.38.2.1Wed Jul 28 18:55:26 2004
+++ php-src/ext/spl/spl_iterators.c Sat Oct 30 06:46:24 2004
@@ -16,7 +16,7 @@
+--+
  */
 
-/* $Id: spl_iterators.c,v 1.38.2.1 2004/07/28 22:55:26 helly Exp $ */
+/* $Id: spl_iterators.c,v 1.38.2.2 2004/10/30 10:46:24 helly Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include config.h
@@ -314,7 +314,7 @@
spl_recursive_it_rewind
 };
 
-/* {{{ proto RecursiveIteratorIterator::__construct(RecursiveIterator $it)
+/* {{{ proto RecursiveIteratorIterator::__construct(RecursiveIterator it [, int flags 
= RIT_LEAVES_ONLY])
Creates a RecursiveIteratorIterator from a RecursiveIterator. */
 SPL_METHOD(RecursiveIteratorIterator, __construct)
 {
@@ -414,8 +414,8 @@
RETURN_LONG(object-level);
 } /* }}} */
 
-/* {{{ proto RecursiveIterator RecursiveIteratorIterator::getSubIterator()
-   The current active sub iterator */
+/* {{{ proto RecursiveIterator RecursiveIteratorIterator::getSubIterator([int level])
+   The current active sub iterator or the iterator at specified level */
 SPL_METHOD(RecursiveIteratorIterator, getSubIterator)
 {
spl_recursive_it_object   *object = 
(spl_recursive_it_object*)zend_object_store_get_object(getThis() TSRMLS_CC);
@@ -839,7 +839,7 @@
spl_filter_it_next(getThis(), intern TSRMLS_CC);
 } /* }}} */
 
-/* {{{ proto ParentIterator::__construct(RecursiveIterator $it)
+/* {{{ proto ParentIterator::__construct(RecursiveIterator it)
Create a ParentIterator from a RecursiveIterator */
 SPL_METHOD(ParentIterator, __construct)
 {
@@ -995,7 +995,7 @@
}
 }
 
-/* {{{ proto LimitIterator::__construct(Iterator $it [, int $offset, int $count])
+/* {{{ proto LimitIterator::__construct(Iterator it [, int offset, int count])
Construct a LimitIterator from an Iterator with a given starting offset and 
optionally a maximum count */
 SPL_METHOD(LimitIterator, __construct)
 {
@@ -1039,7 +1039,7 @@
}
 } /* }}} */
 
-/* {{{ proto void LimitIterator::seek(int $position)
+/* {{{ proto void LimitIterator::seek(int position)
Seek to the given position */
 SPL_METHOD(LimitIterator, seek)
 {
@@ -1187,7 +1187,7 @@
spl_caching_it_next(intern TSRMLS_CC);
 }
 
-/* {{{ proto CachingIterator::__construct(Iterator $it)
+/* {{{ proto CachingIterator::__construct(Iterator it [, flags = CIT_CALL_TOSTRING])
Construct a CachingIterator from an Iterator */
 SPL_METHOD(CachingIterator, __construct)
 {
@@ -1275,7 +1275,7 @@
{NULL, NULL, NULL}
 };
 
-/* {{{ proto CachingRecursiveIterator::__construct(RecursiveIterator $it)
+/* {{{ proto CachingRecursiveIterator::__construct(RecursiveIterator it [, flags = 
CIT_CALL_TOSTRING])
Create an iterator from a RecursiveIterator */
 SPL_METHOD(CachingRecursiveIterator, __construct)
 {

-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php